#!/bin/sh
prefix=/tmp/plot-times-for-bounds
die () {
  echo "plot-times-for-bounds.sh: $*" 1>&2
  rm -f $prefix.*
  exit 1
}
[ $# -lt 1 ] && \
die "expected at least one directory as argument"
order=$prefix.order
for dir in $*
do
  [ -d "$dir" ] || die "argument '$dir' is not a directory"
  times="`awk '/^camical solved bound/{s++}END{print s}' $dir/*.log`"
  echo $times $dir
done | sort -r -n > $order
max="`head -1 $order|awk '{print $1}'`"
echo "maximum $max"
script=$prefix.rscript
pdf=plot.pdf
cat<<EOF>$script
pdf("$pdf",height=5,width=8)
par(mar=c(2.5,2.5,.5,.5))
plot(c(50000,$max+100),c(0,3650),col=0,xlab="",ylab="",main="")
abline(3600,0,lty=3)
EOF
count=1
legend=""
col=1
pch=1
cols=""
pchs=""
for dir in `awk '{print $2}' $order`
do
  echo $dir
  table="$prefix-$dir.table"
  awk '/^camical solved bound/{print $9}' $dir/*.log | \
  sort -n | \
  awk '
    BEGIN { x = 0; y = 0; }
    {
      if (NR >= 45000) {
	c = NR - x;
	d = $1 - y;
        # this shrinks the PDF without changing the look
	if (c > 70 || d > 4) {
	  printf "%.0f %.2lf\n", NR, $1;
	  x = NR;
	  y = $1
	}
      }
    }' > $table

cat<<EOF>>$script
points (read.table ("$table",header=FALSE),col=$col,pch=$pch,type="o")
EOF

  test "$cols" = "" || cols="$cols,"
  cols="$cols\"$col\""

  test "$pchs" = "" || pchs="$pchs,"
  pchs="$pchs$pch"

  test "$legend" = "" || legend="$legend,"
  legend="$legend\"$dir\""

  col=`expr $col + 1`
  test $col = 7 && col=8

  pch=`expr $pch + 1`
  count=`expr $count + 1`
done
cat<<EOF>>$script
legend(x="left",legend=c($legend),col=c($cols),pch=c($pchs),cex=0.8)
EOF
echo "dev.off ()" >>$script
Rscript $script || exit 1
