#!/bin/sh
die () {
  echo "build.sh: error: $* (see also '$log')" 1>&2
  exit 1
}
log=`pwd`/build.log
rm -f $log
[ -d build ] || mkdir build
cd build || exit 1
for i in aiger cadical camical
do
  rm -rf $i*
  archive=../$i-*.tar.xz
  [ -f $archive ] || die "can not find '$archive'"
  base=`basename ../$i-*.tar.xz .tar.xz`
  echo "extracting  $base" | tee -a $log
  tar xf $archive || exit 1
  mv $base $i || exit 1
  cd $i
  echo "configuring $base" | tee -a $log
  ./configure* >>$log || die "configuration of '$i' failed"
  echo "compiling   $base" | tee -a $log
  make >>$log || die "compilation with 'make' of '$i' failed"
  cd ..
done
echo "build successful (see also '$log')"
